@@ -840,14 +840,17 @@ class Askdata(SignUp):
     def get_token(self, username, password):
         return self._token
 
-    def save_dataset(self, df:pd.DataFrame, workspace: str, replace=False, dataset_name="", locale="en"):
+    def save_dataset(self, df:pd.DataFrame, workspace: str, dataset_slug="", replace=False, dataset_name="", locale="en"):
 
         if "/" in workspace:
             agentSlug = workspace.split("/")[0]
             datasetSlug = workspace.split("/")[1]
         else:
             agentSlug = workspace
-            datasetSlug = "parquet_" + uuid.uuid4().__str__()
+            if dataset_slug == "":
+                datasetSlug = "parquet_" + uuid.uuid4().__str__()
+            else:
+                datasetSlug = dataset_slug
 
         url = self.base_url + "/smartbot/agents/{}/datasets/{}/data_table".format(agentSlug, datasetSlug)
 
