@@ -64,7 +64,7 @@ class AskdataPandasExtension:
         self.r1 = r1
 
 
-    def save_dataset(self, workspace:str, replace=False, dataset_name="", locale="en"):
+    def save_dataset(self, workspace:str, dataset_slug="", replace=False, dataset_name="", locale="en"):
 
         if self._env.lower() == 'dev':
             askdata_url = url_list['BASE_URL_ASKDATA_DEV']
@@ -78,7 +78,10 @@ class AskdataPandasExtension:
             datasetSlug = workspace.split("/")[1]
         else:
             agentSlug = workspace
-            datasetSlug = "parquet_" + uuid.uuid4().__str__()
+            if dataset_slug == "":
+                datasetSlug = "parquet_" + uuid.uuid4().__str__()
+            else:
+                datasetSlug = dataset_slug
 
         url = askdata_url + "/smartbot/agents/{}/datasets/{}/data_table".format(agentSlug, datasetSlug)
 
