@@ -40,6 +40,7 @@ Read hubspot contacts as dataframe
 Usage example: read_hubspot_contacts(api_key)
 """
 def read_hubspot_contacts(api_key, offset=100):
-    from integrations import hubspot
+    
+    from askdata.integrations import hubspot
 
     return hubspot.get_contacts(api_key, offset)
\ No newline at end of file
